# Calculating library

# Description

Classic calculation library for Python.

# Usage

Download `calc.py` file from releases and put it in a directory with your project.
Next, in your .py file import this library. For example: `from calc import plus`.

# Commands

Read our [wiki](https://github.com/zhenya194/Calculating-library/wiki) to see the commands of this library.

# Libraries

This project use `pytest` library for tests.

> [!NOTE]
> This library was created and tested on python 3.14.2 version.
